{% extends 'mistral/default/table.html' %}
{% load i18n %}
{% block title %}
    {% trans "Cron Triggers" %}
{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Cron Triggers")%}
{% endblock page_header %}
